@@ -378,7 +378,7 @@ try {
             // Fetch WordPress versions for all sites dynamically
             $siteIds = $_POST['site_ids'] ?? [];
             $versions = [];
-            
+
             foreach ($siteIds as $siteId) {
                 $site = $wpManager->getSite($siteId);
                 if ($site) {
@@ -388,11 +388,124 @@ try {
                     $versions[$siteId] = $version ?: 'Unknown';
                 }
             }
-            
+
             ob_clean();
             echo json_encode(['success' => true, 'versions' => $versions]);
             exit;
-            
+
+        case 'get_site_backups':
+            // Get backups for a specific WordPress site
+            $siteId = $_POST['site_id'] ?? '';
+            if (!$siteId) {
+                throw new Exception('Site ID required');
+            }
+
+            // Get site information
+            $site = $wpManager->getSite($siteId);
+            if (!$site) {
+                throw new Exception('Site not found');
+            }
+
+            // Check permissions
+            if (!$isRoot && $site['user'] !== $username) {
+                throw new Exception('Permission denied');
+            }
+
+            // Get domain for backup filtering
+            $domain = $site['domain'];
+
+            // Query backups for this domain
+            $stmt = $db->prepare("
+                SELECT
+                    bh.id,
+                    bh.backup_name,
+                    bh.backup_path,
+                    bh.backup_size,
+                    bh.backup_type,
+                    bh.status,
+                    bh.upload_status,
+                    bh.started_at,
+                    bh.completed_at,
+                    bh.local_path,
+                    bh.local_deleted_at
+                FROM backup_history bh
+                WHERE bh.user = ?
+                AND bh.backup_name LIKE ?
+                AND bh.backup_type = 'wordpress'
+                AND bh.status = 'completed'
+                ORDER BY bh.started_at DESC
+                LIMIT 50
+            ");
+            $stmt->execute([$site['user'], '%' . $domain . '%']);
+            $backups = $stmt->fetchAll(PDO::FETCH_ASSOC);
+
+            ob_clean();
+            echo json_encode(['success' => true, 'backups' => $backups]);
+            exit;
+
+        case 'restore_backup':
+            // Restore WordPress from backup
+            $siteId = $_POST['site_id'] ?? '';
+            $backupId = $_POST['backup_id'] ?? '';
+
+            if (!$siteId || !$backupId) {
+                throw new Exception('Site ID and Backup ID required');
+            }
+
+            // Get site information
+            $site = $wpManager->getSite($siteId);
+            if (!$site) {
+                throw new Exception('Site not found');
+            }
+
+            // Check permissions
+            if (!$isRoot && $site['user'] !== $username) {
+                throw new Exception('Permission denied');
+            }
+
+            // Get backup information
+            require_once '../libs/BackupHistory.php';
+            require_once '../libs/BackupTarget.php';
+            require_once '../libs/BackupStorage.php';
+
+            use WHPBackup\BackupHistory;
+            use WHPBackup\BackupTarget;
+            use WHPBackup\BackupStorage;
+
+            $backupHistory = new BackupHistory($db, $backupId);
+            $backupData = $backupHistory->getData();
+
+            if (!$backupData) {
+                throw new Exception('Backup not found');
+            }
+
+            // Verify backup belongs to this user
+            if (!$isRoot && $backupData['user'] !== $username) {
+                throw new Exception('Permission denied to access this backup');
+            }
+
+            // Verify backup is completed
+            if ($backupData['status'] !== 'completed') {
+                throw new Exception('Backup is not completed');
+            }
+
+            // Restore the backup
+            $result = $wpManager->restoreWordPressBackup(
+                $site['container_name'],
+                $site['user'],
+                $site['domain'],
+                $backupData,
+                $db
+            );
+
+            if ($result['success']) {
+                ob_clean();
+                echo json_encode(['success' => true, 'message' => $result['message']]);
+            } else {
+                throw new Exception($result['error'] ?? 'Restore failed');
+            }
+            exit;
+
         default:
             throw new Exception('Invalid action');
     }
