@@ -15,6 +15,11 @@ class ApiKeyManager {
             require_once __DIR__ . '/mysqlmgmt.php';
             $MySQLMgmt = new mysqlmgmt();
             $this->db = $MySQLMgmt->getMySQLConnection();
+            
+            // Select the WHP database
+            if ($this->db) {
+                $this->db->exec("USE whp");
+            }
         }
         
         // Initialize logger if available
