@@ -183,13 +183,20 @@ class haproxy_manager {
     }
     
     /**
-     * Request SSL certificate for a domain
-     * 
+     * Request SSL certificate generation/regeneration for a domain
+     * This regenerates the combined PEM file from Let's Encrypt certificates
+     *
      * @param string $domain Domain name
+     * @param bool $force_renewal Force certificate renewal (default: false)
+     * @param bool $include_www Include www subdomain (default: false)
      * @return array Result array with success/error status
      */
-    public function requestCertificate($domain) {
-        return $this->makeApiRequest('POST', '/api/certificates/request', ['domain' => $domain]);
+    public function requestCertificate($domain, $force_renewal = false, $include_www = false) {
+        return $this->makeApiRequest('POST', '/api/certificates/request', [
+            'domains' => [$domain],
+            'force_renewal' => $force_renewal,
+            'include_www' => $include_www
+        ]);
     }
     
     /**
